==> haskell-regex-compat-0.95.2.1-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-regex-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 regex-compat
version:              0.95.2.1
visibility:           public
id:                   regex-compat-0.95.2.1-6r4iKSNuQHkEjgz1ilm8wy
key:                  regex-compat-0.95.2.1-6r4iKSNuQHkEjgz1ilm8wy
license:              BSD-3-Clause
copyright:            Copyright (c) 2006, Christopher Kuklewicz
maintainer:
    Herbert Valerio Riedel <hvr@gnu.org>,
    Andreas Abel

author:               Christopher Kuklewicz
homepage:             https://wiki.haskell.org/Regular_expressions
synopsis:             Replaces/enhances "Text.Regex"
description:
    One module compat layer over <//hackage.haskell.org/package/regex-posix regex-posix> to replace "Text.Regex".

    See also <https://wiki.haskell.org/Regular_expressions> for more information.

category:             Text
abi:                  aebc2f8603560055c44869c92e0fbbe2
exposed:              True
exposed-modules:      Text.Regex
import-dirs:          /usr/lib/ghc-9.2.8/site-local/regex-compat-0.95.2.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/regex-compat-0.95.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-regex-compat
hs-libraries:         HSregex-compat-0.95.2.1-6r4iKSNuQHkEjgz1ilm8wy
depends:
    array-0.5.4.0 base-4.16.4.0
    regex-base-0.94.0.2-6On48UZuN5IJxnL3aRqiWN
    regex-posix-0.96.0.1-Genc39RUTH74GYzEFB6fWq

haddock-interfaces:
    /usr/share/doc/haskell-regex-compat/html/regex-compat.haddock

haddock-html:         /usr/share/doc/haskell-regex-compat/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-regex-compat-0.95.2.1-8-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-regex-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 regex-compat
version:              0.95.2.1
visibility:           public
id:                   regex-compat-0.95.2.1-FJHZPtlQfxdJ4utGNMgjH1
key:                  regex-compat-0.95.2.1-FJHZPtlQfxdJ4utGNMgjH1
license:              BSD-3-Clause
copyright:            Copyright (c) 2006, Christopher Kuklewicz
maintainer:
    Herbert Valerio Riedel <hvr@gnu.org>,
    Andreas Abel

author:               Christopher Kuklewicz
homepage:             https://wiki.haskell.org/Regular_expressions
synopsis:             Replaces/enhances "Text.Regex"
description:
    One module compat layer over <//hackage.haskell.org/package/regex-posix regex-posix> to replace "Text.Regex".

    See also <https://wiki.haskell.org/Regular_expressions> for more information.

category:             Text
abi:                  7010d0340118c67f918878fd45b1462f
exposed:              True
exposed-modules:      Text.Regex
import-dirs:          /usr/lib/ghc-9.2.8/site-local/regex-compat-0.95.2.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/regex-compat-0.95.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-regex-compat
hs-libraries:         HSregex-compat-0.95.2.1-FJHZPtlQfxdJ4utGNMgjH1
depends:
    array-0.5.4.0 base-4.16.4.0
    regex-base-0.94.0.3-5QkTUG2Rv2vEZRXRGODVzk
    regex-posix-0.96.0.1-1Q9XmC5TCrJFDwyeT6H8gP

haddock-interfaces:
    /usr/share/doc/haskell-regex-compat/html/regex-compat.haddock

haddock-html:         /usr/share/doc/haskell-regex-compat/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
